import { PDFViewer } from 'pdfjs-dist/types/web/pdf_viewer';
/**
 * A rectangle as measured by the viewport.
 *
 * @category Type
 */
export type LTWH = {
    /** The x coordinate of the top-left of the rectangle. */
    left: number;
    /** The y coordinate of the top-left of the rectangle. */
    top: number;
    /** Width of the rectangle, relative to top left of the viewport. */
    width: number;
    /** Height of the rectangle, relative to top left of the viewport. */
    height: number;
};
/** @category Type */
export type LTWHP = LTWH & {
    /** 1-Indexed page number */
    pageNumber: number;
};
/**
 * A rectangle as measured by the viewport, with normalised coordinates.
 *
 * @category Type
 */
export type ScaledCoordinates = {
    x1: number;
    y1: number;
    x2: number;
    y2: number;
    width: number;
    height: number;
    /** 1-Indexed page number */
    pageNumber: number;
};
/**
 * Position of a Highlight relative to the viewport.
 *
 * @category Type
 */
export type ViewportPosition = {
    /** Bounding rectangle for the entire highlight. */
    boundingRect: LTWHP;
    /** For text highlights, the rectangular highlights for each block of text. */
    rects: Array<LTWHP>;
};
/**
 * Position of a Highlight with normalised coordinates.
 *
 * @category Type
 */
export type ScaledPosition = {
    /** Bounding rectangle for the entire highlight. */
    boundingRect: ScaledCoordinates;
    /** For text highlights, the rectangular highlights for each block of text. */
    rects: Array<ScaledCoordinates>;
    /** Rarely applicable property of whether coordinates should be in PDF coordinate space.  */
    usePdfCoordinates?: boolean;
};
/**
 * The content of a highlight
 *
 * @category Type
 */
export type Content = {
    text?: string;
    image?: string;
};
/**
 * What type the highlight is. This is the ideal way to determine whether to
 * render it in an AreaHighlight or TextHighlight.
 *
 * @category Enum
 */
export declare enum HighlightType {
    Text = "text",
    Area = "area"
}
export declare enum PdfScalePresets {
    PageActual = "page-actual",
    PageWidth = "page-width",
    PageHeight = "page-height",
    PageFit = "page-fit",
    Auto = "auto"
}
/**
 * The accepted scale values by the PDF.js viewer.
 * Numeric entries accept floats, e.g. 1.2 = 120%
 *
 * @category Type
 */
export type PdfScaleValue = PdfScalePresets | number;
/**
 * This represents a selected (text/mouse) area that has been turned into a
 * highlight. If you are storing highlights, they should be stored as this type.
 *
 * @category Type
 */
export interface Highlight {
    id: string;
    type: HighlightType;
    content?: Content;
    position: ScaledPosition;
}
/**
 * This represents a temporary highlight and is ideal as an intermediary between
 * a selection and a highlight.
 *
 * @category Type
 */
export interface GhostHighlight extends Required<Omit<Highlight, "id">> {
    content: Content;
}
/**
 * This represents a rendered highlight, with its position defined by the page
 * viewport.
 *
 * @category Type
 */
export type ViewportHighlight<T extends Highlight = Highlight> = Omit<T, "position"> & {
    position: ViewportPosition;
};
/**
 * An area or text selection in a PDF Document.
 *
 * @category Type
 */
export type PdfSelection = GhostHighlight & {
    /** Convert the current selection into a temporary highlight */
    makeGhostHighlight(): GhostHighlight;
};
/**
 * A PDF.js page representation. This is the reference type for every page in the PdfHighlighter.
 *
 * @category Type
 */
export type Page = {
    node: HTMLElement;
    /** 1-Index page number */
    number: number;
};
/**
 * All the DOM refs for a group of highlights on one page
 *
 * @category Type
 */
export type HighlightBindings = {
    container: Element;
    textLayer: HTMLElement;
};
/**
 * A popup that can be viewed inside a PdfHighlighter.
 *
 * @category Type
 */
export type Popover = {
    position: ViewportPosition;
};
export interface CommentedHighlight extends Highlight {
    content: Content;
    comment?: string;
}
/**
 * A set of utilities for to control the behaviour of {@link PdfHighlighter}.
 *
 * @category Context
 */
export type PdfHighlighterUtils = {
    /**
     * Checks whether a selection is progress, a ghost highlight, or an edit.
     *
     * @returns - `true` if editing, ghost highlighting, or selecting.
     */
    isEditingOrHighlighting(): boolean;
    /**
     * Get currently selected area or text selection.
     *
     * @returns - current selection or `null` if no selection is being made.
     */
    getCurrentSelection(): PdfSelection | null;
    /**
     * Get the currently present ghost highlight.
     *
     * @return - currently present ghost highlight or `null` if non-existent.
     */
    getGhostHighlight(): GhostHighlight | null;
    /**
     * Cancel any ghost highlight.
     * The selected area will stay selected until the user clicks away.
     */
    removeGhostHighlight(): void;
    /**
     * If enabled, automatic tips/popups inside of a PdfHighlighter will be disabled.
     * Additional niceties will also be provided to prevent new highlights being made.
     */
    toggleEditInProgress(flag?: boolean): void;
    /**
     * Whether an AreaHighlight is being moved/resized, or a manual highlight edit has
     * been toggled.
     *
     * @returns - `true` if AreaHighlight is being edited or edit mode was set.
     */
    isEditInProgress(): boolean;
    /**
     * Whether a mouse selection or text selection is currently being performed.
     *
     * @returns - `true` if mouse selection or text selection is being performed.
     */
    isSelectionInProgress(): boolean;
    /**
     * Scroll to a highlight in this viewer.
     *
     * @param highlight - A highlight provided to the {@link PdfHighlighter} to
     * scroll to.
     */
    scrollToHighlight(highlight: Highlight): void;
    /**
     * Get a reference to the currently used instance of a PDF Viewer.
     *
     * @returns - The currently active PDF Viewer.
     */
    getViewer(): PDFViewer | null;
    /**
     * Get the currently active tip, if any.
     *
     * @returns - the currently active tip or `null` if inactive.
     */
    getTip(): Popover | null;
    /**
     * Set a tip to be displayed in the current PDF Viewer.
     *
     * @param tip - tip to be displayed, or `null` to hide any tip.
     */
    setTip(tip: Popover | null): void;
    /**
     * Callback to update any currently active tip's position. This will make sure
     * the tip is visible above/below its highlight.
     */
    updateTipPosition(): void;
};
/**
 * A set of utilities for rendering highlights. Designed to be used within a
 * highlight container.
 *
 * @category Context
 */
export type HighlightContainerUtils<T extends Highlight = Highlight> = {
    /**
     * The highlight being rendered at this component.
     */
    highlight: ViewportHighlight<T>;
    /**
     * Convert a Viewport rectangle to a scaled rectangle. Can be used
     * for storing and updating area selection highlights, for example.
     *
     * @returns - Scaled/display agnostic rectangle.
     */
    viewportToScaled(rect: LTWHP): ScaledCoordinates;
    /**
     *  Capture a PNG data url of a viewport rectangle.
     *
     * @returns - PNG data url. See https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/Data_URLs
     */
    screenshot(position: LTWH): string;
    /**
     * Whether the highlight has been autoscrolled to.
     */
    isScrolledTo: boolean;
    /**
     * All the DOM refs for the highlights shared on the same page
     * as `highlight`
     */
    highlightBindings: HighlightBindings;
};
